#
# spec file for package trytond_purchase
#
# Copyright (c) 2023 SUSE LLC
# Copyright (c) 2014-2024 Dr. Axel Braun
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#

%if 0%{?suse_version} >= 1550
%define pythons python3
%define mypython python3
%define mysitelib %python3_sitelib
%else
%{?sle15_python_module_pythons}
%define mypython %pythons
%define mysitelib %{expand:%%%{mypython}_sitelib}
%endif

%define majorver 6.0
Name:           trytond_purchase
Version:        %{majorver}.20
Release:        bp156.2.12.1
Summary:        The "purchase" module for the Tryton ERP system
License:        GPL-3.0-only
Group:          Productivity/Office/Management
URL:            http://www.tryton.org/
Source:         http://downloads.tryton.org/%{majorver}/%{name}-%{version}.tar.gz
## Source2:        http://downloads.tryton.org/%{majorver}/%{name}-%{version}.tar.gz.asc
## Source3:        https://keybase.io/cedrickrier/pgp_keys.asc?fingerprint=7C5A4360F6DF81ABA91FD54D6FF50AFE03489130#/%{name}.keyring
BuildRequires:  %{mypython}-devel
BuildRequires:  %{mypython}-pip
BuildRequires:  %{mypython}-setuptools
BuildRequires:  %{mypython}-wheel
BuildRequires:  fdupes
BuildRequires:  python-rpm-generators
BuildRequires:  python-rpm-macros

Requires:       trytond
Requires:       trytond_account
Requires:       trytond_account_invoice
Requires:       trytond_account_product
Requires:       trytond_company
Requires:       trytond_currency
Requires:       trytond_party
Requires:       trytond_product
Requires:       trytond_stock
BuildRoot:      %{_tmppath}/%{name}-%{version}-build
BuildArch:      noarch

%description
The purchase module defines the Purchase model in the Tryton
application platform. The purchase is mainly defined by a party from
which the products will be purchased and a list of purchase lines,
each one containing a product and a quantity.

%prep
%setup -q

%build
%pyproject_wheel

%install
%pyproject_install
%python_expand %fdupes %{buildroot}%{mysitelib}

%files
%defattr(-,root,root)
%{mysitelib}/tryton*

%changelog
* Wed Mar  5 2025 Axel Braun <axel.braun@gmx.de>
- Version 6.0.20 - Bugfix Release
* Mon Dec  2 2024 Axel Braun <axel.braun@gmx.de>
- Version 6.0.19 - Bugfix Release
* Tue Oct  8 2024 Axel Braun <axel.braun@gmx.de>
- Version 6.0.18 - Bugfix Release
* Sat Aug  3 2024 Axel Braun <axel.braun@gmx.de>
- Version 6.0.17 - Bugfix Release
* Tue Jul  2 2024 Axel Braun <axel.braun@gmx.de>
- Version 6.0.16 - Bugfix Release
* Tue May  7 2024 Axel Braun <axel.braun@gmx.de>
- Version 6.0.15 - Bugfix Release
* Mon Apr 29 2024 Axel Braun <axel.braun@gmx.de>
- sources not signed anymore
* Sat Jan 13 2024 Axel Braun <axel.braun@gmx.de>
- Switch to wheel and %%{?sle15_python_module_pythons}
* Sat Nov 18 2023 Axel Braun <axel.braun@gmx.de>
- Version 6.0.14 - Bugfix Release
* Sat Nov  4 2023 Axel Braun <axel.braun@gmx.de>
- Version 6.0.13 - Bugfix Release
* Thu Oct 19 2023 Daniel Garcia Moreno <daniel.garcia@suse.com>
- Remove %%python3_install prefix and root options, that's included in
  the macro by default.
* Sun Oct  8 2023 Axel Braun <axel.braun@gmx.de>
- Version 6.0.12 - Bugfix Release
* Sat May 20 2023 Axel Braun <axel.braun@gmx.de>
- Version 6.0.11 - Bugfix Release
* Sun Mar  5 2023 Axel Braun <axel.braun@gmx.de>
- Version 6.0.10 - Bugfix Release
* Tue Oct 18 2022 Axel Braun <axel.braun@gmx.de>
- Version 6.0.9 - Bugfix Release
* Thu Aug  4 2022 Axel Braun <axel.braun@gmx.de>
- Version 6.0.8 - Bugfix Release
* Sat Jun  4 2022 Axel Braun <axel.braun@gmx.de>
- Version 6.0.7 - Bugfix Release
* Wed Mar  2 2022 Axel Braun <axel.braun@gmx.de>
- Version 6.0.6 - Bugfix Release
* Fri Feb 18 2022 Axel Braun <axel.braun@gmx.de>
- Version 6.0.5 - Bugfix Release
* Sat Feb 12 2022 Axel Braun <axel.braun@gmx.de>
- Version bump to Tryton 6.0 series
* Mon Dec  6 2021 Axel Braun <axel.braun@gmx.de>
- Version 5.0.9 - Bugfix Release
* Fri Jun 18 2021 Axel Braun <axel.braun@gmx.de>
- Version 5.0.7 - Bugfix Release
* Wed Mar  3 2021 Axel Braun <axel.braun@gmx.de>
- Version 5.0.6 - Bugfix Release
* Sat Feb 27 2021 Andreas Stieger <andreas.stieger@gmx.de>
- add upstream signing key and validate source signature
* Sun Jan 24 2021 Axel Braun <axel.braun@gmx.de>
- Adaption to new python macros
* Thu Jul  2 2020 Axel Braun <axel.braun@gmx.de>
- Version 5.0.5 - Bugfix Release
* Sat May 16 2020 Axel Braun <axel.braun@gmx.de>
- Version 5.0.4 - Bugfix Release
* Sat Apr  4 2020 Axel Braun <axel.braun@gmx.de>
- Version 5.0.3 - Bugfix Release
* Thu Nov 21 2019 Axel Braun <axel.braun@gmx.de>
- version 5.0.2 (GNU Health 3.6 series)
* Wed Feb 20 2019 Axel Braun <axel.braun@gmx.de>
- Version 4.6.5 - Bugfix Release
* Wed Jul 11 2018 axel.braun@gmx.de
- Version 4.6.4 - Bugfix Release
* Wed Jul 11 2018 axel.braun@gmx.de
- Version 4.2.6 - Bugfix Release (boo#1107771)
* Sat May 12 2018 axel.braun@gmx.de
- Version 4.2.5 - Bugfix Release
* Fri Mar  2 2018 axel.braun@gmx.de
- Version 4.2.4 - Bugfix Release
* Thu Nov  9 2017 axel.braun@gmx.de
- Version 4.2.3 - Bugfix Release
* Sat Sep  9 2017 axel.braun@gmx.de
- Version 4.2.2 - Bugfix Release
* Fri Mar 10 2017 axel.braun@gmx.de
- Version 4.2.1
* Mon Nov 28 2016 axel.braun@gmx.de 
- Tryton Release 4.2
* Mon May  2 2016 axel.braun@gmx.de 
- Tryton Release 4.0
* Mon Oct 19 2015 axel.braun@gmx.de 
- Tryton Release 3.8
* Wed Apr 15 2015 axel.braun@gmx.de 
- Tryton Release 3.6
* Fri Oct 25 2013 axel.braun@gmx.de
- new branch 3.0
* Thu May  2 2013 axel.braun@gmx.de
- initial build
